/* Generated data from bsedefs.h (by make bsenotifier_array.c) */

  { "destroy", "BseObject", },
  { "name_set", "BseObject", },
  { "param_changed", "BseObject", },
  { "store", "BseObject", },
  { "icon_changed", "BseObject", },
  { "lock_changed", "BseGConfig", },
  { "io_changed", "BseSource", },
  { "item_added", "BseContainer", },
  { "item_removed", "BseContainer", },
  { "cross_changes", "BseContainer", },
  { "seqid_changed", "BseItem", },
  { "set_parent", "BseItem", },
  { "size_changed", "BsePattern", },
  { "note_changed", "BsePattern", },
  { "note_selection_changed", "BsePattern", },
  { "pattern_inserted", "BsePatternGroup", },
  { "pattern_removed", "BsePatternGroup", },
  { "pattern_group_inserted", "BseSong", },
  { "pattern_group_removed", "BseSong", },
  { "sequencer_step", "BseSong", },
  { "complete_restore", "BseProject", },

/* Generated data ends here */
